# Python bindings for the Cranelift compiler.

This package is a thin python wrapper around the [Cranelift](https://github.com/bytecodealliance/wasmtime/tree/main/cranelift) compiler.

It is pretty much a direct translation of the [Rust API](https://docs.rs/cranelift/latest/cranelift/) to Python, with some simplifications.

For usage check out the [example file](./example/example.py).